@@ -11,11 +11,11 @@ START_BYTE = 0x0f
 
 END_BYTE = 0x04
 
-LOW_PRIORITY = 0xfb
-
 HIGH_PRIORITY = 0xf8
-
-FIRMWARE_PRIORITY = 0xf7
+FIRMWARE_PRIORITY = 0xf9
+THIRD_PARTY_PRIORITY = 0xfa
+LOW_PRIORITY = 0xfb
+PRIORITY = [HIGH_PRIORITY, FIRMWARE_PRIORITY, THIRD_PARTY_PRIORITY, LOW_PRIORITY] 
 
 LOW_ADDRESS = 0x00
 
